Index: trunk/psModules/src/astrom/pmFPAWrite.h
===================================================================
--- trunk/psModules/src/astrom/pmFPAWrite.h	(revision 6872)
+++ trunk/psModules/src/astrom/pmFPAWrite.h	(revision 6896)
@@ -5,16 +5,23 @@
 #include "pmFPA.h"
 
+bool pmReadoutWriteNext(pmReadout *readout, // Readout to write
+                        psFits *fits,   // FITS file to which to write
+                        int z           // Image plane to write
+                       );
 
 bool pmCellWrite(pmCell *cell,          // Cell to write
                  psFits *fits,          // FITS file to which to write
-                 psDB *db               // Database handle for "concepts" update
+                 psDB *db,              // Database handle for "concepts" update
+                 bool pixels            // Write the pixels?
                 );
 bool pmChipWrite(pmChip *chip,          // Chip to write
                  psFits *fits,          // FITS file to which to write
-                 psDB *db               // Database handle for "concepts" update
+                 psDB *db,              // Database handle for "concepts" update
+                 bool pixels            // Write the pixels?
                 );
 bool pmFPAWrite(pmFPA *fpa,             // FPA to write
                 psFits *fits,           // FITS file to which to write
-                psDB *db                // Database handle for "concepts" update
+                psDB *db,               // Database handle for "concepts" update
+                bool pixels             // Write the pixels?
                );
 
